"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.preferredTzToDefaultTimezone = exports.requestDateConversion = exports.countryToUtcConversion = exports.utcToOtherTimezoneConversion = exports.wrongPhToUtcConversion = void 0;
var Formatter_1 = require("./Formatter");
var wrongPhToUtcConversion = function (phTime) {
    if (phTime && phTime.constructor === String) {
        var sub = phTime.substring(0, 19);
        var utcDatetime = new Date("".concat(sub, "+08")).toLocaleString('en-US', { timeZone: 'UTC' });
        var formattedDatetime = (0, Formatter_1.datetimeFormatter)(utcDatetime, 'datetime-utc-semifull');
        return formattedDatetime;
    }
    else {
        return null;
    }
};
exports.wrongPhToUtcConversion = wrongPhToUtcConversion;
var utcToOtherTimezoneConversion = function (utc, tz) {
    if (utc && (utc.constructor === String || utc.constructor === Date)) {
        var convertedDate = void 0;
        if (utc.constructor === String) {
            var searchRegExp = /[/]/gi;
            var replaceWith = '-';
            var utcReplaced = utc.replace(searchRegExp, replaceWith);
            utcReplaced = utcReplaced.replace(" UTC ", "");
            convertedDate = new Date(utcReplaced).toLocaleString('en-US', { timeZone: tz });
        }
        else {
            convertedDate = new Date(utc).toLocaleString('en-US', { timeZone: tz });
        }
        return (0, Formatter_1.datetimeFormatter)(convertedDate, 'datetime-standard');
    }
    else {
        return null;
    }
};
exports.utcToOtherTimezoneConversion = utcToOtherTimezoneConversion;
var countryToUtcConversion = function (phTime, gmt) {
    var sub = phTime.substring(0, 19);
    var utcDatetime = new Date("".concat(sub).concat(gmt)).toLocaleString('en-US', { timeZone: 'UTC' });
    var formattedDatetime = (0, Formatter_1.datetimeFormatter)(utcDatetime, 'datetime-utc-semifull');
    return formattedDatetime;
};
exports.countryToUtcConversion = countryToUtcConversion;
var requestDateConversion = function (date, offSet, tz) {
    if (date && (date.constructor === String || date.constructor === Date)) {
        var requestDate = date + " 00:00:00 " + offSet;
        var minutes = 1439; //declaring the total number of minutes in 23hours,59minutes
        var convertedFromRequestDate = (0, exports.utcToOtherTimezoneConversion)(requestDate, tz);
        var currentDate = new Date(requestDate); // just need this to add 1439 minutes
        var convertedToRequestDate = new Date(currentDate.getTime() + minutes * 60000);
        convertedToRequestDate = (0, exports.utcToOtherTimezoneConversion)(convertedToRequestDate, tz);
        return {
            from: convertedFromRequestDate,
            to: convertedToRequestDate
        };
    }
    else {
        return null;
    }
};
exports.requestDateConversion = requestDateConversion;
var preferredTzToDefaultTimezone = function (dateTime, tz, tzOffset, isDateOnly) {
    if (isDateOnly === void 0) { isDateOnly = false; }
    if (dateTime && (dateTime.constructor === String || dateTime.constructor === Date)) {
        if (isDateOnly) {
            //getting the time first then adding it on the date only value
            var dt = (0, exports.utcToOtherTimezoneConversion)('2022/01/02 00:00:00 +00', tz);
            if (dt) {
                var prefferedTime = (0, Formatter_1.datetimeFormatter)(dt, 'time');
                return (0, exports.utcToOtherTimezoneConversion)(dateTime + ' ' + prefferedTime + ' ' + tzOffset, 'Asia/Manila');
            }
        }
        else {
            return (0, exports.utcToOtherTimezoneConversion)(dateTime + ' ' + tzOffset, 'Asia/Manila');
        }
    }
    else {
        return null;
    }
};
exports.preferredTzToDefaultTimezone = preferredTzToDefaultTimezone;
