"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.datetimeFormatter = exports.addZero = exports.getUTCFullTime = exports.MONTH_NAMES_FULL = exports.MONTH_NAMES = exports.DAY_WEEK_NAMES_FULL = exports.DAY_WEEK_NAMES = void 0;
exports.DAY_WEEK_NAMES = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
exports.DAY_WEEK_NAMES_FULL = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Sat'];
exports.MONTH_NAMES = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
exports.MONTH_NAMES_FULL = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
/**
* getUTCFullTime
* Getting the utc fulltime
*/
var getUTCFullTime = function (d) {
    if (Object.prototype.toString.call(d) === '[object Date]') {
        var h = (0, exports.addZero)(d.getUTCHours());
        var m = (0, exports.addZero)(d.getUTCMinutes());
        var s = (0, exports.addZero)(d.getUTCSeconds());
        return h + ":" + m + ":" + s;
    }
    else {
        return '';
    }
};
exports.getUTCFullTime = getUTCFullTime;
var addZero = function (i) {
    if (i < 10) {
        i = "0" + i;
    }
    return i;
};
exports.addZero = addZero;
/**
* datetimeFormat
* format datetime values
* @param {*} timestamp - it can be string or date format or object if its from v3 utc datetime
* sample format if its object = {dateTimeStamp:'2021-09-26 23:54:55+00',source:'v3'}
* @param {*} format - string only, each format value will have a corresponding return string
*/
var datetimeFormatter = function (timestamp, format) {
    if (timestamp && (timestamp.constructor === String || timestamp.constructor === Date || (timestamp.constructor === Object && timestamp.dateTimeStamp))) {
        var date = void 0;
        var iosDate = void 0;
        var arrayDate = [];
        if (timestamp === "today") {
            date = new Date();
        }
        else {
            if (timestamp && timestamp.constructor === String) {
                timestamp = timestamp.replace('+00', ''); //removing unnecessary gmt from backend as the time is already in ph
                arrayDate = timestamp.split(/[- :.]/);
            }
            else if (timestamp.constructor === Object && timestamp.dateTimeStamp && timestamp.source && timestamp.source === "v3") {
                // this will be used if the datetime from api is set to UTC already
                timestamp = timestamp.dateTimeStamp;
                arrayDate = timestamp.split(/[- :.]/);
            }
            //supporting the ios devices for the time
            if (arrayDate.length === 3) {
                iosDate = new Date(arrayDate[0], arrayDate[1] - 1, arrayDate[2], arrayDate[3]);
            }
            else if (arrayDate.length >= 5 && arrayDate.length <= 8) {
                iosDate = new Date(arrayDate[0], arrayDate[1] - 1, arrayDate[2], arrayDate[3], arrayDate[4], arrayDate[5]);
            }
            else if (arrayDate.length >= 9) {
                // new implementation for safari and for the node datetime
                iosDate = new Date(arrayDate[0] + " " + arrayDate[1] + " " + arrayDate[2] + " " + arrayDate[3] + " " + arrayDate[4] + ":" + arrayDate[5] + ":" + arrayDate[6] + " GMT");
            }
            else {
                iosDate = new Date(timestamp);
            }
            var currentTz = Intl.DateTimeFormat().resolvedOptions().timeZone;
            var localeStringDate = new Date(timestamp).toLocaleString('en-US', { timeZone: currentTz }); //making the date picked as the default gmt so that the new date wont adjust by timezone
            date = new Date(localeStringDate);
        }
        if ((date && date.toString() !== 'Invalid Date') || (iosDate && iosDate.toString() !== 'Invalid Date')) { //checking if datetime is still not readable
            //get DATE
            var dayName = exports.DAY_WEEK_NAMES[isNaN(date.getDay()) ? iosDate.getDay() : date.getDay()];
            var dayNameFull = exports.DAY_WEEK_NAMES_FULL[isNaN(date.getDay()) ? iosDate.getDay() : date.getDay()];
            var dayDate = ("0" + (isNaN(date.getDate()) ? iosDate.getDate() : date.getDate())).slice(-2);
            var monthName = exports.MONTH_NAMES[isNaN(date.getMonth()) ? iosDate.getMonth() : date.getMonth()];
            var monthNameFull = exports.MONTH_NAMES_FULL[isNaN(date.getMonth()) ? iosDate.getMonth() : date.getMonth()];
            var year = isNaN(date.getFullYear()) ? iosDate.getFullYear() : date.getFullYear();
            var MonthNumeric = ("0" + (isNaN(date.getMonth()) ? (iosDate.getMonth() + 1) : (date.getMonth() + 1))).slice(-2);
            var firstDay = new Date(year, isNaN(date.getMonth()) ? iosDate.getMonth() : date.getMonth(), 1);
            var lastDay = new Date(year, (isNaN(date.getMonth()) ? iosDate.getMonth() : date.getMonth()) + 1, 0);
            var monthFirstDay = ("0" + firstDay.getDate()).slice(-2);
            var monthLastDay = ("0" + lastDay.getDate()).slice(-2);
            //get TIME
            var hours = isNaN(date.getHours()) ? iosDate.getHours() : date.getHours();
            var minutes = isNaN(date.getMinutes()) ? iosDate.getMinutes() : date.getMinutes();
            var seconds = isNaN(date.getSeconds()) ? iosDate.getSeconds() : date.getSeconds();
            var ampm = hours >= 12 ? 'PM' : 'AM';
            hours = hours % 12;
            hours = hours ? hours : 12; // the hour '0' should be '12'
            minutes = minutes < 10 ? '0' + minutes : minutes;
            seconds = seconds < 10 ? '0' + seconds : seconds;
            var strTime = hours + ':' + minutes + ' ' + ampm;
            var today = new Date();
            var todayTS = Math.round((today).getTime() / 1000);
            var dateTS = Math.round((date).getTime() / 1000);
            switch (format) {
                case "datetime":
                    // Mon, 01 Jan 2020 at 12:00PM
                    return dayName + ", " + dayDate + " " + monthName + " " + year + " at " + strTime;
                case "datetime-no-at":
                    // Mon, 01 Jan 2020, 12:00PM
                    return dayName + ", " + dayDate + " " + monthName + " " + year + ", " + strTime;
                case "datetime-no-day":
                    // 01 Jan 2020 at 12:00PM
                    return dayDate + " " + monthName + " " + year + " at " + strTime;
                case "date":
                    // Mon, 01 Jan 2020
                    return dayName + ", " + dayDate + " " + monthName + " " + year;
                case "momentsAgoClimax":
                    if (todayTS >= dateTS) {
                        //check if 24hours has been passed
                        if (todayTS >= (dateTS + 86400)) {
                            var diff = todayTS - dateTS;
                            if (diff == 0) {
                                return "1 day";
                            }
                            var diffDay = diff / 86400;
                            diffDay = ~~diffDay;
                            return diffDay == 1 ? "1 day" : diffDay + " days";
                        }
                        else {
                            return "0 day";
                        }
                    }
                    else {
                        return "0 day";
                    }
                case "inquiry-date-standard":
                    return dayDate + " " + monthName + " " + year;
                //10 Feb 2021
                case "date-standard":
                    return year + "-" + MonthNumeric + "-" + dayDate;
                //2021-02-10
                case "datetime-standard":
                    return year + "-" + MonthNumeric + "-" + dayDate + ' ' + ("0".concat(date.getHours())).slice(-2) + ':' + ("0".concat(date.getMinutes())).slice(-2);
                //2021-02-10 15:49
                case "datetime-standard-full":
                    return year + "-" + MonthNumeric + "-" + dayDate + ' ' + (0, exports.addZero)(date.getHours()) + ':' + (0, exports.addZero)(date.getMinutes()) + ':00';
                    //2021-02-10 15:49:00
                    break;
                case "day-fulldate":
                    return dayNameFull + " " + dayDate + " " + monthName + " " + year;
                    //Monday 05 oct 2022
                    break;
                case "full-year":
                    return year;
                    //2021
                    break;
                case "full-month":
                    return monthNameFull;
                    //February
                    break;
                case "month-year":
                    return monthName.substring(0, 3) + " " + year;
                    //Feb 2021
                    break;
                case "full-month-year":
                    return monthNameFull + " " + year;
                    //February 2021
                    break;
                case "datetime-format-forPosting":
                    var forPostingDay = String(date.getUTCDate());
                    if (forPostingDay.length === 1) {
                        forPostingDay = "0" + forPostingDay;
                    }
                    return date.getUTCFullYear() + '-' + (0, exports.addZero)(date.getUTCMonth() + 1) + '-' + forPostingDay + 'T' + (0, exports.getUTCFullTime)(date) + 'Z';
                    //2021-02-10T07:57:05Z
                    break;
                case "month-day-year":
                    return monthNameFull + " " + dayDate + ", " + year;
                    //February 10, 2021
                    break;
                case "time":
                    return strTime;
                    //3:58 PM
                    break;
                case "month-numeric":
                    return (0, exports.addZero)(date.getUTCMonth() + 1);
                    //02
                    break;
                case "month-shortName":
                    return monthName.substring(0, 3);
                    //Feb
                    break;
                case "day-numeric":
                    return date.getUTCDate();
                    //10
                    break;
                case "day-calendar":
                    return dayDate;
                    //10
                    break;
                case "month-first-date":
                    return year + "-" + MonthNumeric + "-" + monthFirstDay;
                    break;
                case "month-last-date":
                    return year + "-" + MonthNumeric + "-" + monthLastDay;
                    break;
                case "day-name":
                    return dayName;
                case "day-name-full":
                    return dayNameFull;
                case 'month-day':
                    return MonthNumeric + '-' + dayDate;
                    break;
                case "time-standard":
                    var h = isNaN(date.getHours()) ? iosDate.getHours() : date.getHours();
                    var hour = h < 10 ? '0' + h : h;
                    return hour + ':' + minutes;
                    // 15:30
                    break;
                case 'notif-date':
                    // 01-Jan-2020
                    return dayDate + "-" + monthName + "-" + year;
                    break;
                case 'year-month':
                    return year + "-" + MonthNumeric;
                    break;
                case "datetime-utc":
                    return year + "-" + MonthNumeric + "-" + dayDate + ' 00:00:00+00';
                    //2021-02-10 00:00:00+00
                    break;
                case "datetime-utc-semifull":
                    return year + "-" + MonthNumeric + "-" + dayDate + ' ' + (0, exports.addZero)(date.getHours()) + ':' + (0, exports.addZero)(date.getMinutes()) + ':' + (0, exports.addZero)(date.getSeconds()) + '+00';
                    //2021-02-10 15:49:20+00
                    break;
                case 'datetime-file-format':
                    hours = isNaN(date.getHours()) ? iosDate.getHours() : date.getHours();
                    hours = hours < 10 ? '0' + hours : hours;
                    return year + "-" + "".concat(MonthNumeric) + "".concat(date.getUTCDate()) + "".concat(hours) + "".concat(minutes) + "".concat(seconds) + "".concat('1');
                    break;
                case 'datetime-file-format-generator':
                    hours = isNaN(date.getHours()) ? iosDate.getHours() : date.getHours();
                    hours = hours < 10 ? '0' + hours : hours;
                    return year + "-" + MonthNumeric + "-" + dayDate + '_' + date.getHours() + ':' + date.getMinutes() + ':' + seconds;
                    //2021-02-10 15:49
                    break;
                default:
                    return "";
            }
        }
        else {
            return "";
        }
    }
    else {
        return "";
    }
};
exports.datetimeFormatter = datetimeFormatter;
